@@ -1,6 +1,6 @@
 /*
  *  XMMP - LinuX MultiMedia Project ( www.frozenproductions.com )
- *  Copyright (c) 1999 - 2001 Arthur Kleer <kleer@frozenproductions.com>
+ *  Copyright (c) 1999 - 2002 Arthur Kleer <kleer@frozenproductions.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include <sys/stat.h>
   
 #include <gtk/gtk.h>
-#include "interface.h"
+//#include "interface.h"
 
 #include <libxmm/libxmm.h>
 #include <libxmm/util/utils.h>
@@ -39,6 +39,10 @@
 #include "main.h"
 #include "deftheme.h"
 
+#include "wabout/about.h"
+#include "wclipinfo/clipinfo.h"
+#include "wprefs/prefs.h"
+
 #include <gdk/gdkx.h>
 
 /*
@@ -487,9 +491,11 @@ static void mplayer_callback( mptTheme *theme, mptWidget *widget, mptEvent *even
 
 static void mainwin_menucallback( GtkWidget *widget, gpointer data )
 {
+  XMM_ClipInfo ci;
+
   switch( (int) data )
   {
-	case MAINMENU_ABOUT:		mp_AboutWin();
+	case MAINMENU_ABOUT:		display_mplayer_about();
 					break;
 
 	case MAINMENU_LOAD:		on_eject_release( 0 );
@@ -512,7 +518,8 @@ static void mainwin_menucallback( GtkWidget *widget, gpointer data )
 					mplayer_WidgetDrawAll( &mainwin_theme );
 					break;
 
-	case MAINMENU_FILEINFO:		xmmplay_InputDialogue( xmmplay, XMM_GTKDLG_INFO );
+	case MAINMENU_FILEINFO:		xmmplay_Info( xmmplay, NULL, &ci, NULL );
+    					display_mplayer_clipinfo( "hallo", &ci, xmmplay );
 					break;
 
 	case MAINMENU_VIEW_ORIG:	xmmplay_Scale( xmmplay, 0, 0, XMM_GRAPH_RESIZE_ORIG );
@@ -539,7 +546,7 @@ static void mainwin_menucallback( GtkWidget *widget, gpointer data )
 	case MAINMENU_PLAY_RANDOM:	on_random_release( 0 );
 					break;
 
-	case MAINMENU_OPTIONS_PREF:	mp_PrefWin( xmmplay );
+	case MAINMENU_OPTIONS_PREF:	display_mplayer_prefs( xmmplay );
 					break;
 
 	case MAINMENU_OPTIONS_SKIN:	mplayer_SkinBrowser();
@@ -653,7 +660,7 @@ static void on_position_change( int value )
   double	position;
   gchar		*text;
 
-  xmmplay_Info( xmmplay, NULL, &ci, NULL, NULL );
+  xmmplay_Info( xmmplay, NULL, &ci, NULL );
   position = ( value * ci.playtime ) / 100;
 
   text = g_strdup_printf( "SEEK: %i:%.2i:%.2i/%i:%.2i:%.2i ( %i%% )",
@@ -720,14 +727,81 @@ static void on_menubar_release( int value )
 static void skinwin_restore_info( void )
 {
   XMM_ClipInfo	ci;
-  char		*ptr;
+  char		*ptr, ch, *format = cfg_DisplayFormat, temp[512];
+  int		idx;
 
   if( xmmplay_Status( xmmplay ) > -1 )
   {
-	xmmplay_Info( xmmplay, NULL, &ci, NULL, NULL );
-	ptr = g_strdup_printf( "%s ( %i:%.2i )", ci.name, XMMPLAY_TIME_M( ci.playtime ), XMMPLAY_TIME_S( ci.playtime ));
-	mpwTextBoxSetText( mainwin_info, ptr );
-	g_free( ptr );
+	xmmplay_Info( xmmplay, NULL, &ci, NULL );
+
+	for( idx = 0, ptr = temp; format[idx]; idx++ )
+	{
+	    if( format[idx] != '%' )	*ptr++ = format[idx];
+	    else
+	    {
+		ch = format[++idx];
+		switch( ch )
+		{
+		    case 0:	idx--;
+				*ptr++ = '%';
+				break;
+
+		    case '%':	*ptr++ = '%';
+				break;		    
+
+		    case '1':	strcpy( ptr, ci.author );
+				ptr += strlen( ci.author );
+				break;
+
+		    case '2':	strcpy( ptr, ci.name );
+				ptr += strlen( ci.name );
+				break;
+
+		    case '3':	strcpy( ptr, ci.album );
+				ptr += strlen( ci.album );
+				break;
+
+		    case '4':	strcpy( ptr, ci.content );
+				ptr += strlen( ci.content );
+				break;
+
+		    case '5':	strcpy( ptr, ci.copyright );
+				ptr += strlen( ci.copyright );
+				break;
+
+		    case '6':	strcpy( ptr, ci.software );
+				ptr += strlen( ci.software );
+				break;
+
+		    case '7':	strcpy( ptr, ci.comment );
+				ptr += strlen( ci.comment );
+				break;
+
+		    case '8':	sprintf( ptr, "%c%c.%c%c.%c%c%c%c\n",
+						ci.date[0], ci.date[1],
+						ci.date[2], ci.date[3],
+						ci.date[4], ci.date[5],
+						ci.date[6], ci.date[7] );
+				ptr += 10;
+				break;
+
+		    case 'f':	*ptr++ = ' ';		/* file name */
+				break;	
+
+		    case 'e':	*ptr++ = ' ';		/* file extension */
+				break;	
+
+		    case 'F':	*ptr++ = ' ';		/* file path */
+				break;
+
+		    default:	*ptr++ = ch;		/* not any defined format */
+				break;
+		}
+	    }
+	}
+
+	sprintf( ptr, " ( %i:%.2i:%.2i )", XMMPLAY_TIME_H( ci.playtime ), XMMPLAY_TIME_M( ci.playtime ), XMMPLAY_TIME_S( ci.playtime ));
+	mpwTextBoxSetText( mainwin_info, temp );
   }
   else	mpwTextBoxSetText( mainwin_info, "LinuX Media Player " XMM_VERSION_STRING );
 }
@@ -758,13 +832,13 @@ static gint timer_proc( gpointer data )
 	return TRUE;
   }
 
-  ctime = xmmplay_Info( xmmplay, NULL, NULL, NULL, &seekval );
+  ctime = xmmplay_Info( xmmplay, NULL, NULL, &seekval );
   mpwSliderSetValue( mainwin_position, (int)( seekval * 100 ));
 
-  mpwNumberSetValue( mainwin_time_h, XMMPLAY_TIME_H( ctime ));
-  mpwNumberSetValue( mainwin_time_m, XMMPLAY_TIME_M( ctime ));
-  mpwNumberSetValue( mainwin_time_s, XMMPLAY_TIME_S( ctime ));
-  playlist_UpdateDisplay( XMMPLAY_TIME_H( ctime ), XMMPLAY_TIME_M( ctime ), XMMPLAY_TIME_S( ctime ));
+  mpwNumberSetValue( mainwin_time_h, XMMPLAY_PTS_H( ctime ));
+  mpwNumberSetValue( mainwin_time_m, XMMPLAY_PTS_M( ctime ));
+  mpwNumberSetValue( mainwin_time_s, XMMPLAY_PTS_S( ctime ));
+  playlist_UpdateDisplay( XMMPLAY_PTS_H( ctime ), XMMPLAY_PTS_M( ctime ), XMMPLAY_PTS_S( ctime ));
 
   /* Event handling */
   if( xmm_PollEvent( XMMPLAY_2XMM(xmmplay), 0, &event ) <= 0 )	return TRUE;
@@ -855,16 +929,16 @@ static int FileOpen( char *filename )
 	mpwSliderSetValue( mainwin_position, 0 );
 	mpwStatusSetStatus( mainwin_pmode, 2 );
 
-	xmmplay_Info( xmmplay, &xmm_info, &ci, NULL, NULL );	// Check for playtime
+	xmmplay_Info( xmmplay, &xmm_info, &ci, NULL );	/* Get playtime */
 	if( ci.playtime == -1 )	mplayer_WidgetVisible( mainwin_position, 0 );
 
-	sprintf( buffer, "%i", abs( xmm_info.ai[0].bitrate ) / 1000 );
+	sprintf( buffer, "%i", abs( xmm_info.ai[0].fmt.bitrate ) / 1000 );
 	mpwTextBoxSetText( mainwin_info_rate, buffer );
 
-	sprintf( buffer, "%i", xmm_info.ai[0].format.samprate / 1000 );
+	sprintf( buffer, "%i", xmm_info.ai[0].fmt.samprate / 1000 );
 	mpwTextBoxSetText( mainwin_info_freq, buffer );
 
-	mpwStatusSetStatus( mainwin_chmode, xmm_info.ai[0].format.channels & 1 );
+	mpwStatusSetStatus( mainwin_chmode, xmm_info.ai[0].fmt.channels & 1 );
 
 	mplayer_WidgetDrawAll( &mainwin_theme );
 	skinwin_restore_info();
